==> qtjambi-designer-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiDesigner/QDesignerWidgetFactoryInterface_shell.h <==
#ifndef QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H
#define QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractwidgetfactory.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetFactoryInterface_shell : public QDesignerWidgetFactoryInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetFactoryInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerWidgetFactoryInterface_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* containerOfWidget(QWidget* w0) const override;
    QDesignerFormEditorInterface* core() const override;
    QLayout* createLayout(QWidget* widget0, QLayout* layout1, int type2) const override;
    QWidget* createWidget(const QString& name0, QWidget* parentWidget1) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize(QObject* object0) const override;
    bool isPassiveInteractor(QWidget* widget0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widgetOfContainer(QWidget* w0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetFactoryInterface_access : public QDesignerWidgetFactoryInterface
{
    jobject __qt_containerOfWidget_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0) const;
    jobject __qt_core_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createLayout_QWidget_ptr_QLayout_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, QtJambiNativeID layout1, jint type2) const;
    jobject __qt_createWidget_cref_QString_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, QtJambiNativeID parentWidget1) const;
    void __qt_initialize_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jboolean __qt_isPassiveInteractor_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jobject __qt_widgetOfContainer_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0) const;
};

#endif // QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H

==> qtjambi-designer-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiDesigner/QDesignerWidgetFactoryInterface_shell.h <==
#ifndef QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H
#define QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractwidgetfactory.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetFactoryInterface_shell : public QDesignerWidgetFactoryInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetFactoryInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerWidgetFactoryInterface_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* containerOfWidget(QWidget* w0) const override;
    QDesignerFormEditorInterface* core() const override;
    QLayout* createLayout(QWidget* widget0, QLayout* layout1, int type2) const override;
    QWidget* createWidget(const QString& name0, QWidget* parentWidget1) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize(QObject* object0) const override;
    bool isPassiveInteractor(QWidget* widget0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widgetOfContainer(QWidget* w0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetFactoryInterface_access : public QDesignerWidgetFactoryInterface
{
    jobject __qt_containerOfWidget_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0) const;
    jobject __qt_core(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createLayout_QWidget_ptr_QLayout_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, QtJambiNativeID layout1, jint type2) const;
    jobject __qt_createWidget_cref_QString_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, QtJambiNativeID parentWidget1) const;
    void __qt_initialize_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jboolean __qt_isPassiveInteractor_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jobject __qt_widgetOfContainer_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0) const;
};

#endif // QDESIGNERWIDGETFACTORYINTERFACE_SHELL_H
